==> android-aihelp-aar-2.4.4-sources.jar: net/aihelp/ui/helper/AttachmentPicker.java <==
package net.aihelp.ui.helper;

import android.content.ActivityNotFoundException;
import android.content.ContentResolver;
import android.content.Context;
import android.content.Intent;
import android.database.Cursor;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.text.TextUtils;

import net.aihelp.common.Const;
import net.aihelp.config.AIHelpContext;
import net.aihelp.ui.cs.ConversationFragment;
import net.aihelp.utils.FileUtil;

import java.lang.ref.WeakReference;
import java.util.UUID;

import androidx.fragment.app.Fragment;


public class AttachmentPicker {

    public static final int PICK_IMAGE = 1;
    public static final int PICK_VIDEO = 2;

    public static final int ATTACHMENT_FILE_NOT_FOUND = -1;
    public static final int UNSUPPORTED_ATTACHMENT_TYPE = -2;
    public static final int ATTACHMENT_FILE_SIZE_LIMIT_EXCEEDED = -3;
    public static final int NO_APPS_TO_OPEN_ATTACHMENTS_INTENT = -4;
    public static final int INVALID_URI = -5;

    private static final long MAX_ATTACHMENT_FILE_SIZE_LIMIT = 26214400L;

    private WeakReference<ConversationFragment> attachmentPickerListenerRef;
    private Bundle extraData;
    private int pickType;

    public AttachmentPicker setPickerHost(ConversationFragment fragment) {
        attachmentPickerListenerRef = new WeakReference<>(fragment);
        return this;
    }

    public void launchImagePicker(boolean hasPermission) {
        startActivityForResult(AttachmentDataProvider.getIntentForMedia(),
                hasPermission ? AttachmentDataProvider.PICK_ATTACHMENT_REQUEST_ID :
                        AttachmentDataProvider.PICK_ATTACHMENT_WITHOUT_PERMISSIONS_REQUEST_ID);
    }

    public void onAttachmentPickRequestResult(int requestCode, Intent intent) {
        Uri uri = intent.getData();
        if (requestCode == AttachmentDataProvider.PICK_ATTACHMENT_REQUEST_ID) {
            processUriForAttachment(uri);
        }
    }

    private void processUriForAttachment(Uri uri) {
        if (isUriValid(uri)) {
            Context context = AIHelpContext.getInstance().getContext();
            if (FileUtil.doesFileFromUriExistAndCanRead(uri, context)) {
                AttachmentPickerFile file = createPickFileFromUri(uri);
                Long fileSize = file.originalFileSize;
                long limitSize = Math.max(Const.LIMIT_UPLOADING_VIDEO, MAX_ATTACHMENT_FILE_SIZE_LIMIT);
                if (file.attachmentType == PICK_VIDEO && fileSize != null && fileSize > limitSize
                        || file.attachmentType == PICK_IMAGE && fileSize != null && fileSize > limitSize) {
                    sendPickFailure(ATTACHMENT_FILE_SIZE_LIMIT_EXCEEDED, limitSize);
                } else {
                    sendPickSuccess(file, extraData);
                }

            } else {
                sendPickFailure(ATTACHMENT_FILE_NOT_FOUND, null);
            }
        } else {
            sendPickFailure(INVALID_URI, null);
        }
    }

    private boolean isUriValid(Uri uri) {
        return uri != null;
    }

    private AttachmentPickerFile createPickFileFromUri(Uri uri) {
        Context context = AIHelpContext.getInstance().getContext();
        ContentResolver contentResolver = context.getContentResolver();
        Cursor cursor = contentResolver.query(uri, null, null, null, null);
        Long size = null;
        String displayName = null;
        String mime = null;

        try {
            if (cursor != null && cursor.moveToFirst()) {
                displayName = cursor.getString(cursor.getColumnIndex("_display_name"));
                mime = contentResolver.getType(uri);
                if (TextUtils.isEmpty(displayName)) {
                    displayName = UUID.randomUUID().toString();
                }

                int sizeIndex = cursor.getColumnIndex("_size");
                if (!cursor.isNull(sizeIndex)) {
                    String sizeString = cursor.getString(sizeIndex);
                    if (sizeString != null) {
                        try {
                            size = Long.valueOf(sizeString);
                        } catch (NumberFormatException e) {
                            e.printStackTrace();
                        }
                    }
                }
            }
        } finally {
            if (cursor != null) {
                cursor.close();
            }

        }

        AttachmentPickerFile attachmentPickerFile = new AttachmentPickerFile(uri, displayName, size);
        if (!TextUtils.isEmpty(mime) && mime.startsWith("video/")) {
            attachmentPickerFile.attachmentType = PICK_VIDEO;
        } else {
            attachmentPickerFile.attachmentType = PICK_IMAGE;
        }

        return attachmentPickerFile;
    }

    private void sendPickSuccess(AttachmentPickerFile attachmentPickerFile, Bundle extraData) {
        AttachmentPickerListener attachmentPickerListener = this.attachmentPickerListenerRef.get();
        if (attachmentPickerListener != null) {
            attachmentPickerListener.onPickSuccess(attachmentPickerFile, extraData);
        }

    }

    private void sendPickFailure(int errorCode, Long data) {
        AttachmentPickerListener attachmentPickerListener = this.attachmentPickerListenerRef.get();
        if (attachmentPickerListener != null) {
            attachmentPickerListener.onPickFailure(errorCode, data);
        }
    }

    private void startActivityForResult(Intent intent, int requestCode) {
        try {
            Fragment fragment = this.attachmentPickerListenerRef.get();
            if (fragment != null && fragment.getActivity() != null) {
                fragment.startActivityForResult(intent, requestCode);
            }
        } catch (ActivityNotFoundException var4) {
            this.sendPickFailure(NO_APPS_TO_OPEN_ATTACHMENTS_INTENT, null);
        }
    }

    public interface AttachmentPickerListener {

        void onPickSuccess(AttachmentPickerFile var1, Bundle var2);

        void onPickFailure(int errCode, Long limitSize);
    }

    private static final class LazyHolder {
        static final AttachmentPicker INSTANCE = new AttachmentPicker();

        private LazyHolder() {
        }

    }

    public static AttachmentPicker getInstance() {
        return AttachmentPicker.LazyHolder.INSTANCE;
    }

}

==> android-aihelp-aar-3.3.12-sources.jar: net/aihelp/ui/helper/AttachmentPicker.java <==
package net.aihelp.ui.helper;

import android.content.ActivityNotFoundException;
import android.content.ContentResolver;
import android.content.Context;
import android.content.Intent;
import android.database.Cursor;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.text.TextUtils;

import net.aihelp.common.Const;
import net.aihelp.config.AIHelpContext;
import net.aihelp.ui.cs.ConversationFragment;
import net.aihelp.utils.FileUtil;

import java.lang.ref.WeakReference;
import java.util.UUID;

import androidx.fragment.app.Fragment;


public class AttachmentPicker {

    public static final int ATTACHMENT_FILE_NOT_FOUND = -1;
    public static final int UNSUPPORTED_ATTACHMENT_TYPE = -2;
    public static final int ATTACHMENT_FILE_SIZE_LIMIT_EXCEEDED = -3;
    public static final int NO_APPS_TO_OPEN_ATTACHMENTS_INTENT = -4;
    public static final int INVALID_URI = -5;

    private static final long MAX_ATTACHMENT_FILE_SIZE_LIMIT = 26214400L;

    private WeakReference<ConversationFragment> attachmentPickerListenerRef;
    private Bundle extraData;
    private int pickType;

    public AttachmentPicker setPickerHost(ConversationFragment fragment) {
        attachmentPickerListenerRef = new WeakReference<>(fragment);
        return this;
    }

    public void launchImagePicker(boolean hasPermission) {
        startActivityForResult(AttachmentDataProvider.getIntentForMedia(hasPermission),
                hasPermission ? AttachmentDataProvider.PICK_ATTACHMENT_REQUEST_ID :
                        AttachmentDataProvider.PICK_ATTACHMENT_WITHOUT_PERMISSIONS_REQUEST_ID);
    }

    public void onAttachmentPickRequestResult(int requestCode, Intent intent) {
        Uri uri = intent.getData();
        switch (requestCode) {
            case AttachmentDataProvider.PICK_ATTACHMENT_REQUEST_ID:
                processUriForAttachment(uri);
                break;
            case AttachmentDataProvider.PICK_ATTACHMENT_WITHOUT_PERMISSIONS_REQUEST_ID:
                Context context = AIHelpContext.getInstance().getContext();
                context.grantUriPermission(context.getPackageName(), uri, Intent.FLAG_GRANT_READ_URI_PERMISSION);
                processUriForAttachment(uri);
                break;
        }
    }

    private void processUriForAttachment(Uri uri) {
        if (uri != null) {
            Context context = AIHelpContext.getInstance().getContext();
            if (FileUtil.doesFileFromUriExistAndCanRead(uri, context)) {
                AttachmentPickerFile file = AttachmentHelper.createPickFileFromUri(uri);
                Long fileSize = file.originalFileSize;
                long limitSize = Math.max(Const.LIMIT_UPLOADING_VIDEO, MAX_ATTACHMENT_FILE_SIZE_LIMIT);
                if (file.attachmentType == AttachmentHelper.PICK_VIDEO && fileSize != null && fileSize > limitSize
                        || file.attachmentType == AttachmentHelper.PICK_IMAGE && fileSize != null && fileSize > limitSize) {
                    sendPickFailure(ATTACHMENT_FILE_SIZE_LIMIT_EXCEEDED, limitSize);
                } else {
                    sendPickSuccess(file, extraData);
                }

            } else {
                sendPickFailure(ATTACHMENT_FILE_NOT_FOUND, null);
            }
        } else {
            sendPickFailure(INVALID_URI, null);
        }
    }

    private void sendPickSuccess(AttachmentPickerFile attachmentPickerFile, Bundle extraData) {
        AttachmentPickerListener attachmentPickerListener = this.attachmentPickerListenerRef.get();
        if (attachmentPickerListener != null) {
            attachmentPickerListener.onPickSuccess(attachmentPickerFile, extraData);
        }

    }

    private void sendPickFailure(int errorCode, Long data) {
        AttachmentPickerListener attachmentPickerListener = this.attachmentPickerListenerRef.get();
        if (attachmentPickerListener != null) {
            attachmentPickerListener.onPickFailure(errorCode, data);
        }
    }

    private void startActivityForResult(Intent intent, int requestCode) {
        try {
            Fragment fragment = this.attachmentPickerListenerRef.get();
            if (fragment != null && fragment.getActivity() != null) {
                fragment.startActivityForResult(intent, requestCode);
            }
        } catch (ActivityNotFoundException var4) {
            this.sendPickFailure(NO_APPS_TO_OPEN_ATTACHMENTS_INTENT, null);
        }
    }

    public interface AttachmentPickerListener {

        void onPickSuccess(AttachmentPickerFile var1, Bundle var2);

        void onPickFailure(int errCode, Long limitSize);
    }

    private static final class LazyHolder {
        static final AttachmentPicker INSTANCE = new AttachmentPicker();

        private LazyHolder() {
        }

    }

    public static AttachmentPicker getInstance() {
        return AttachmentPicker.LazyHolder.INSTANCE;
    }

}
